﻿Imports System
Imports System.Windows.Forms
Imports ThinkGeo.MapSuite.Core
Imports ThinkGeo.MapSuite.DesktopEdition
Imports System.Collections.ObjectModel

Namespace VBSampleApps
    Public Class TrackAndEditShapes
        Inherits UserControl
        Public Sub New()
            InitializeComponent()
        End Sub

        Private Sub TrackAndEditShapes_Load(ByVal sender As Object, ByVal e As EventArgs) Handles MyBase.Load
            AddHandler winformsMap1.TrackOverlay.TrackEnded, AddressOf TrackOverlay_TrackEnded

            winformsMap1.MapUnit = GeographyUnit.DecimalDegree
            winformsMap1.CurrentExtent = New RectangleShape(-139.2, 92.4, 120.9, -93.2)
            winformsMap1.BackgroundOverlay.BackgroundBrush = New GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean)

            Dim worldMapKitDesktopOverlay As LayerOverlay = New LayerOverlay()
            worldMapKitDesktopOverlay.Layers.Add("PointLayer", New InMemoryFeatureLayer())
            winformsMap1.Overlays.Add(worldMapKitDesktopOverlay)

            Dim worldLayer As New ShapeFileFeatureLayer("..\..\SampleData\Data\Countries02.shp")
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Transparent, GeoColor.FromArgb(100, GeoColor.SimpleColors.Green))
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20

            Dim staticOverlay As New LayerOverlay()
            staticOverlay.Layers.Add("WorldLayer", worldLayer)
            winformsMap1.Overlays.Add(staticOverlay)

            winformsMap1.Refresh()
        End Sub

        Private Sub TrackOverlay_TrackEnded(ByVal sender As Object, ByVal e As TrackEndedTrackInteractiveOverlayEventArgs)
            Dim pointLayer As InMemoryFeatureLayer = DirectCast(winformsMap1.FindFeatureLayer("PointLayer"), InMemoryFeatureLayer)
            pointLayer.Open()
            Dim count As Integer = pointLayer.QueryTools.GetCount()

        End Sub

        Private Sub button_Click(ByVal sender As Object, ByVal e As EventArgs)
            Dim button As Button = TryCast(sender, Button)
            If button IsNot Nothing Then
                Select Case button.Name
                    Case "btnTrackNormal"
                        winformsMap1.TrackOverlay.TrackMode = TrackMode.None
                        Exit Select
                    Case "btnTrackPoint"
                        winformsMap1.TrackOverlay.TrackMode = TrackMode.Point
                        Exit Select
                    Case "btnTrackLine"
                        winformsMap1.TrackOverlay.TrackMode = TrackMode.Line
                        Exit Select
                    Case "btnTrackRectangle"
                        winformsMap1.TrackOverlay.TrackMode = TrackMode.Rectangle
                        Exit Select
                    Case "btnTrackSquare"
                        winformsMap1.TrackOverlay.TrackMode = TrackMode.Square
                        Exit Select
                    Case "btnTrackPolygon"
                        winformsMap1.TrackOverlay.TrackMode = TrackMode.Polygon
                        Exit Select
                    Case "btnTrackCircle"
                        winformsMap1.TrackOverlay.TrackMode = TrackMode.Circle
                        Exit Select
                    Case "btnTrackEllipse"
                        winformsMap1.TrackOverlay.TrackMode = TrackMode.Ellipse
                        Exit Select
                    Case "btnTrackEdit"
                        winformsMap1.TrackOverlay.TrackMode = TrackMode.None

                        For Each feature As Feature In winformsMap1.TrackOverlay.TrackShapeLayer.InternalFeatures
                            winformsMap1.EditOverlay.EditShapesLayer.InternalFeatures.Add(feature)
                        Next
                        winformsMap1.EditOverlay.CalculateAllControlPoints()
                        winformsMap1.TrackOverlay.TrackShapeLayer.InternalFeatures.Clear()

                        winformsMap1.Refresh(New Overlay() {winformsMap1.EditOverlay, winformsMap1.TrackOverlay})
                        Exit Select
                    Case "btnTrackDelete"
                        ' should use TrackMode.EditShape select a shape, and then call DeleteTrackShape(); 
                        Dim lastIndex As Integer = winformsMap1.EditOverlay.EditShapesLayer.InternalFeatures.Count - 1
                        If (lastIndex >= 0) Then
                            winformsMap1.EditOverlay.EditShapesLayer.InternalFeatures.RemoveAt(lastIndex)
                            winformsMap1.EditOverlay.CalculateAllControlPoints()
                        End If

                        winformsMap1.Refresh(winformsMap1.EditOverlay)
                        Exit Select
                    Case Else
                        winformsMap1.TrackOverlay.TrackMode = TrackMode.None
                        Exit Select
                End Select
            End If
        End Sub

#Region "Component Designer generated code"
        Private components As System.ComponentModel.IContainer = Nothing
        Private WithEvents groupBox1 As System.Windows.Forms.GroupBox
        Private WithEvents btnTrackNormal As System.Windows.Forms.Button
        Private WithEvents btnTrackPoint As System.Windows.Forms.Button
        Private WithEvents btnTrackLine As System.Windows.Forms.Button
        Private WithEvents btnTrackRectangle As System.Windows.Forms.Button
        Private WithEvents btnTrackSquare As System.Windows.Forms.Button
        Private WithEvents btnTrackPolygon As System.Windows.Forms.Button
        Private WithEvents btnTrackCircle As System.Windows.Forms.Button
        Private WithEvents btnTrackEllipse As System.Windows.Forms.Button
        Private WithEvents btnTrackEdit As System.Windows.Forms.Button
        Private WithEvents btnTrackDelete As System.Windows.Forms.Button
        Private winformsMap1 As WinformsMap

        ''' <summary> 
        ''' Clean up any resources being used.
        ''' </summary>
        ''' <param name="disposing">true if managed resources should be disposed; otherwise, false.</param>
        Protected Overloads Overrides Sub Dispose(ByVal disposing As Boolean)
            If disposing AndAlso (components IsNot Nothing) Then
                components.Dispose()
            End If
            MyBase.Dispose(disposing)
        End Sub

        ''' <summary> 
        ''' Required method for Designer support - do not modify 
        ''' the contents of this method with the code editor.
        ''' </summary>
        Private Sub InitializeComponent()
            Me.winformsMap1 = New ThinkGeo.MapSuite.DesktopEdition.WinformsMap
            Me.groupBox1 = New System.Windows.Forms.GroupBox
            Me.btnTrackNormal = New System.Windows.Forms.Button
            Me.btnTrackPoint = New System.Windows.Forms.Button
            Me.btnTrackLine = New System.Windows.Forms.Button
            Me.btnTrackRectangle = New System.Windows.Forms.Button
            Me.btnTrackSquare = New System.Windows.Forms.Button
            Me.btnTrackPolygon = New System.Windows.Forms.Button
            Me.btnTrackCircle = New System.Windows.Forms.Button
            Me.btnTrackEllipse = New System.Windows.Forms.Button
            Me.btnTrackEdit = New System.Windows.Forms.Button
            Me.btnTrackDelete = New System.Windows.Forms.Button
            Me.groupBox1.SuspendLayout()
            Me.SuspendLayout()
            '
            'winformsMap1
            '
            Me.winformsMap1.BackColor = System.Drawing.Color.White
            Me.winformsMap1.Dock = System.Windows.Forms.DockStyle.Fill
            Me.winformsMap1.Location = New System.Drawing.Point(0, 0)
            Me.winformsMap1.Name = "winformsMap1"
            Me.winformsMap1.Size = New System.Drawing.Size(740, 528)
            Me.winformsMap1.TabIndex = 0
            Me.winformsMap1.Text = "winformsMap1"
            '
            'groupBox1
            '
            Me.groupBox1.Anchor = CType((System.Windows.Forms.AnchorStyles.Top Or System.Windows.Forms.AnchorStyles.Right), System.Windows.Forms.AnchorStyles)
            Me.groupBox1.BackColor = System.Drawing.Color.Transparent
            Me.groupBox1.Controls.Add(Me.btnTrackNormal)
            Me.groupBox1.Controls.Add(Me.btnTrackPoint)
            Me.groupBox1.Controls.Add(Me.btnTrackLine)
            Me.groupBox1.Controls.Add(Me.btnTrackRectangle)
            Me.groupBox1.Controls.Add(Me.btnTrackSquare)
            Me.groupBox1.Controls.Add(Me.btnTrackPolygon)
            Me.groupBox1.Controls.Add(Me.btnTrackCircle)
            Me.groupBox1.Controls.Add(Me.btnTrackEllipse)
            Me.groupBox1.Controls.Add(Me.btnTrackEdit)
            Me.groupBox1.Controls.Add(Me.btnTrackDelete)
            Me.groupBox1.Location = New System.Drawing.Point(370, 1)
            Me.groupBox1.Name = "groupBox1"
            Me.groupBox1.Size = New System.Drawing.Size(370, 60)
            Me.groupBox1.TabIndex = 6
            Me.groupBox1.TabStop = False
            Me.groupBox1.Text = "Functions"
            '
            'btnTrackNormal
            '
            Me.btnTrackNormal.BackColor = System.Drawing.SystemColors.Control
            Me.btnTrackNormal.Image = Global.VBSampleApps.My.Resources.Resources.Normal
            Me.btnTrackNormal.Location = New System.Drawing.Point(7, 20)
            Me.btnTrackNormal.Name = "btnTrackNormal"
            Me.btnTrackNormal.Size = New System.Drawing.Size(30, 30)
            Me.btnTrackNormal.TabIndex = 0
            Me.btnTrackNormal.UseVisualStyleBackColor = False
            AddHandler btnTrackNormal.Click, AddressOf button_Click
            '
            'btnTrackPoint
            '
            Me.btnTrackPoint.BackColor = System.Drawing.SystemColors.Control
            Me.btnTrackPoint.Image = Global.VBSampleApps.My.Resources.Resources.Point
            Me.btnTrackPoint.Location = New System.Drawing.Point(43, 20)
            Me.btnTrackPoint.Name = "btnTrackPoint"
            Me.btnTrackPoint.Size = New System.Drawing.Size(30, 30)
            Me.btnTrackPoint.TabIndex = 1
            Me.btnTrackPoint.UseVisualStyleBackColor = False
            AddHandler btnTrackPoint.Click, AddressOf button_Click
            '
            'btnTrackLine
            '
            Me.btnTrackLine.BackColor = System.Drawing.SystemColors.Control
            Me.btnTrackLine.Image = Global.VBSampleApps.My.Resources.Resources.Line
            Me.btnTrackLine.Location = New System.Drawing.Point(79, 20)
            Me.btnTrackLine.Name = "btnTrackLine"
            Me.btnTrackLine.Size = New System.Drawing.Size(30, 30)
            Me.btnTrackLine.TabIndex = 2
            Me.btnTrackLine.UseVisualStyleBackColor = False
            AddHandler btnTrackLine.Click, AddressOf button_Click
            '
            'btnTrackRectangle
            '
            Me.btnTrackRectangle.BackColor = System.Drawing.SystemColors.Control
            Me.btnTrackRectangle.Image = Global.VBSampleApps.My.Resources.Resources.Rectangle
            Me.btnTrackRectangle.Location = New System.Drawing.Point(115, 20)
            Me.btnTrackRectangle.Name = "btnTrackRectangle"
            Me.btnTrackRectangle.Size = New System.Drawing.Size(30, 30)
            Me.btnTrackRectangle.TabIndex = 3
            Me.btnTrackRectangle.UseVisualStyleBackColor = False
            AddHandler btnTrackRectangle.Click, AddressOf button_Click
            '
            'btnTrackSquare
            '
            Me.btnTrackSquare.BackColor = System.Drawing.SystemColors.Control
            Me.btnTrackSquare.Image = Global.VBSampleApps.My.Resources.Resources.Square
            Me.btnTrackSquare.Location = New System.Drawing.Point(151, 20)
            Me.btnTrackSquare.Name = "btnTrackSquare"
            Me.btnTrackSquare.Size = New System.Drawing.Size(30, 30)
            Me.btnTrackSquare.TabIndex = 4
            Me.btnTrackSquare.UseVisualStyleBackColor = False
            AddHandler btnTrackSquare.Click, AddressOf button_Click
            '
            'btnTrackPolygon
            '
            Me.btnTrackPolygon.BackColor = System.Drawing.SystemColors.Control
            Me.btnTrackPolygon.Image = Global.VBSampleApps.My.Resources.Resources.Polygon
            Me.btnTrackPolygon.Location = New System.Drawing.Point(187, 20)
            Me.btnTrackPolygon.Name = "btnTrackPolygon"
            Me.btnTrackPolygon.Size = New System.Drawing.Size(30, 30)
            Me.btnTrackPolygon.TabIndex = 5
            Me.btnTrackPolygon.UseVisualStyleBackColor = False
            AddHandler btnTrackPolygon.Click, AddressOf button_Click
            '
            'btnTrackCircle
            '
            Me.btnTrackCircle.BackColor = System.Drawing.SystemColors.Control
            Me.btnTrackCircle.Image = Global.VBSampleApps.My.Resources.Resources.Circle
            Me.btnTrackCircle.Location = New System.Drawing.Point(223, 20)
            Me.btnTrackCircle.Name = "btnTrackCircle"
            Me.btnTrackCircle.Size = New System.Drawing.Size(30, 30)
            Me.btnTrackCircle.TabIndex = 6
            Me.btnTrackCircle.UseVisualStyleBackColor = False
            AddHandler btnTrackCircle.Click, AddressOf button_Click
            '
            'btnTrackEllipse
            '
            Me.btnTrackEllipse.BackColor = System.Drawing.SystemColors.Control
            Me.btnTrackEllipse.Image = Global.VBSampleApps.My.Resources.Resources.Ellipse
            Me.btnTrackEllipse.Location = New System.Drawing.Point(259, 20)
            Me.btnTrackEllipse.Name = "btnTrackEllipse"
            Me.btnTrackEllipse.Size = New System.Drawing.Size(30, 30)
            Me.btnTrackEllipse.TabIndex = 7
            Me.btnTrackEllipse.UseVisualStyleBackColor = False
            AddHandler btnTrackEllipse.Click, AddressOf button_Click
            '
            'btnTrackEdit
            '
            Me.btnTrackEdit.BackColor = System.Drawing.SystemColors.Control
            Me.btnTrackEdit.Image = Global.VBSampleApps.My.Resources.Resources.Edit
            Me.btnTrackEdit.Location = New System.Drawing.Point(295, 20)
            Me.btnTrackEdit.Name = "btnTrackEdit"
            Me.btnTrackEdit.Size = New System.Drawing.Size(30, 30)
            Me.btnTrackEdit.TabIndex = 8
            Me.btnTrackEdit.UseVisualStyleBackColor = False
            AddHandler btnTrackEdit.Click, AddressOf button_Click
            '
            'btnTrackDelete
            '
            Me.btnTrackDelete.BackColor = System.Drawing.SystemColors.Control
            Me.btnTrackDelete.Image = Global.VBSampleApps.My.Resources.Resources.Delete
            Me.btnTrackDelete.Location = New System.Drawing.Point(331, 20)
            Me.btnTrackDelete.Name = "btnTrackDelete"
            Me.btnTrackDelete.Size = New System.Drawing.Size(30, 30)
            Me.btnTrackDelete.TabIndex = 9
            Me.btnTrackDelete.UseVisualStyleBackColor = False
            AddHandler btnTrackDelete.Click, AddressOf button_Click
            '
            'TrackAndEditShapes
            '
            Me.AutoScaleDimensions = New System.Drawing.SizeF(6.0!, 13.0!)
            Me.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font
            Me.Controls.Add(Me.groupBox1)
            Me.Controls.Add(Me.winformsMap1)
            Me.Name = "TrackAndEditShapes"
            Me.Size = New System.Drawing.Size(740, 528)
            Me.groupBox1.ResumeLayout(False)
            Me.ResumeLayout(False)

        End Sub
#End Region
    End Class
End Namespace
